summaryrefslogtreecommitdiffstats
path: root/tdeui/knuminput.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:13 -0600
commit56160bf4dfe503631ef6373367b281f081bab2b4 (patch)
tree7fcea2ffd9c3420af999c3dcad0ed032eef93956 /tdeui/knuminput.h
parent13281e2856a2ef43bbab78c5528470309c23aa77 (diff)
downloadtdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.tar.gz
tdelibs-56160bf4dfe503631ef6373367b281f081bab2b4.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 13281e2856a2ef43bbab78c5528470309c23aa77.
Diffstat (limited to 'tdeui/knuminput.h')
-rw-r--r--tdeui/knuminput.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/tdeui/knuminput.h b/tdeui/knuminput.h
index 5f0127cda..c0a6d1847 100644
--- a/tdeui/knuminput.h
+++ b/tdeui/knuminput.h
@@ -68,7 +68,7 @@ public:
~KNumInput();
/**
* Sets the text and alignment of the main description label.
*
* @param label The text of the label.
* Use TQString::null to remove an existing one.
@@ -77,7 +77,7 @@ public:
* @p AlignTop, @p AlignVCenter, @p AlignBottom.
* default is @p AlignLeft | @p AlignTop.
*
* The vertical alignment flags have special meaning with this
* widget:
*
* @li @p AlignTop The label is placed above the edit/slider
@@ -144,7 +144,7 @@ protected:
TQSlider* m_slider;
TQSize m_sizeSlider, m_sizeLabel;
- int m_alignment;
+ int m_tqalignment;
private:
void init();
@@ -314,7 +314,7 @@ public:
/**
* This method returns the minimum size necessary to display the
* control. The minimum size is enough to show all the labels
- * in the current font (font change may invalidate the return value).
+ * in the current font (font change may tqinvalidate the return value).
*
* @return the minimum size necessary to show the control
*/
@@ -68,7 +68,7 @@ public:
~KNumInput();
/**
- * Sets the text and alignment of the main description label.
+ * Sets the text and tqalignment of the main description label.
*
* @param label The text of the label.
@@ -77,7 +77,7 @@ public:
* default is @p AlignLeft | @p AlignTop.
*
- * The vertical alignment flags have special meaning with this
+ * The vertical tqalignment flags have special meaning with this
* widget:
*